@@ -20,19 +20,22 @@
 #endif
 #include <log4cxx/helpers/aprinitializer.h>
 #include <apr_pools.h>
-#include <apr_atomic.h>
 #include <assert.h>
 #include <log4cxx/helpers/threadspecificdata.h>
-#include <apr_thread_mutex.h>
 #include <apr_thread_proc.h>
 #include <log4cxx/helpers/filewatchdog.h>
 #include <log4cxx/helpers/date.h>
+#include <log4cxx/helpers/loglog.h>
+#include <list>
+#include <algorithm>
 
-using namespace log4cxx::helpers;
-using namespace log4cxx;
+using namespace LOG4CXX_NS::helpers;
+using namespace LOG4CXX_NS;
 
 bool APRInitializer::isDestructed = false;
 
+using IdentifiedObject = std::pair<size_t, ObjectPtr>;
+
 struct APRInitializer::APRInitializerPrivate{
 	APRInitializerPrivate() :
 		p(0),
@@ -40,22 +43,38 @@ struct APRInitializer::APRInitializerPrivate{
 		tlsKey(0){
 
 	}
+	~APRInitializerPrivate()
+	{
+		// Delete in reverse order
+		while (!objects.empty())
+			objects.pop_back();
+	}
 
 	apr_pool_t* p;
 	std::mutex mutex;
 	std::list<FileWatchdog*> watchdogs;
 	log4cxx_time_t startTime;
 	apr_threadkey_t* tlsKey;
-	std::map<size_t, ObjectPtr> objects;
+	std::vector<IdentifiedObject> objects;
 };
 
 namespace
 {
-extern "C" void tlsDestruct(void* ptr)
+void tlsDestructImpl(void* ptr)
 {
 	delete ((ThreadSpecificData*) ptr);
 }
+}
 
+#if LOG4CXX_ABI_VERSION <= 15
+extern "C" void tlsDestruct(void* ptr)
+{
+	return tlsDestructImpl(ptr);
+}
+#endif
+
+namespace
+{
 // The first object created and the last object destroyed
 struct apr_environment
 {
@@ -71,15 +90,14 @@ struct apr_environment
 
 }
 
+
 APRInitializer::APRInitializer() :
 	m_priv(std::make_unique<APRInitializerPrivate>())
 {
 	apr_pool_create(&m_priv->p, NULL);
-	apr_atomic_init(m_priv->p);
 	m_priv->startTime = Date::currentTime();
 #if APR_HAS_THREADS
-	apr_status_t stat = apr_threadkey_private_create(&m_priv->tlsKey, tlsDestruct, m_priv->p);
-	assert(stat == APR_SUCCESS);
+	apr_status_t stat = apr_threadkey_private_create(&m_priv->tlsKey, tlsDestructImpl, m_priv->p);
 	assert(stat == APR_SUCCESS);
 #endif
 }
@@ -89,19 +107,18 @@ APRInitializer::~APRInitializer()
 	stopWatchDogs();
 	isDestructed = true;
 #if APR_HAS_THREADS
-	std::unique_lock<std::mutex> lock(m_priv->mutex);
+	std::lock_guard<std::mutex> lock(m_priv->mutex);
 	apr_threadkey_private_delete(m_priv->tlsKey);
 #endif
 }
 
 void APRInitializer::stopWatchDogs()
 {
-#if APR_HAS_THREADS
-	std::unique_lock<std::mutex> lock(m_priv->mutex);
-#endif
+	std::lock_guard<std::mutex> lock(m_priv->mutex);
 
 	while (!m_priv->watchdogs.empty())
 	{
+		m_priv->watchdogs.back()->stop();
 		delete m_priv->watchdogs.back();
 		m_priv->watchdogs.pop_back();
 	}
@@ -114,16 +131,23 @@ void APRInitializer::unregisterAll()
 
 APRInitializer& APRInitializer::getInstance()
 {
-	static apr_environment env;
-	static APRInitializer init;
+	static WideLife<apr_environment> env;
+	static WideLife<APRInitializer> init;
 	return init;
 }
 
 
+#if LOG4CXX_ABI_VERSION <= 15
 log4cxx_time_t APRInitializer::initialize()
 {
 	return getInstance().m_priv->startTime;
 }
+#endif
+
+log4cxx_time_t APRInitializer::getStartTime()
+{
+	return getInstance().m_priv->startTime;
+}
 
 apr_pool_t* APRInitializer::getRootPool()
 {
@@ -138,46 +162,45 @@ apr_threadkey_t* APRInitializer::getTlsKey()
 void APRInitializer::registerCleanup(FileWatchdog* watchdog)
 {
 	APRInitializer& instance(getInstance());
-#if APR_HAS_THREADS
-	std::unique_lock<std::mutex> lock(instance.m_priv->mutex);
-#endif
+	std::lock_guard<std::mutex> lock(instance.m_priv->mutex);
 	instance.m_priv->watchdogs.push_back(watchdog);
 }
 
 void APRInitializer::unregisterCleanup(FileWatchdog* watchdog)
 {
 	APRInitializer& instance(getInstance());
-#if APR_HAS_THREADS
-	std::unique_lock<std::mutex> lock(instance.m_priv->mutex);
-#endif
+	std::lock_guard<std::mutex> lock(instance.m_priv->mutex);
 
-	for (std::list<FileWatchdog*>::iterator iter = instance.m_priv->watchdogs.begin();
-		iter != instance.m_priv->watchdogs.end();
-		iter++)
-	{
-		if (*iter == watchdog)
-		{
-			instance.m_priv->watchdogs.erase(iter);
-			return;
-		}
-	}
+	auto iter = std::find(instance.m_priv->watchdogs.begin(), instance.m_priv->watchdogs.end(), watchdog);
+	if (iter != instance.m_priv->watchdogs.end())
+		instance.m_priv->watchdogs.erase(iter);
 }
 
 void APRInitializer::addObject(size_t key, const ObjectPtr& pObject)
 {
-#if APR_HAS_THREADS
-	std::unique_lock<std::mutex> lock(m_priv->mutex);
-#endif
-	m_priv->objects[key] = pObject;
+	std::lock_guard<std::mutex> lock(m_priv->mutex);
+	auto pItem = std::find_if(m_priv->objects.begin(), m_priv->objects.end()
+		, [key](const IdentifiedObject& item) { return item.first == key; }
+		);
+	if (m_priv->objects.end() != pItem)
+		pItem->second = pObject;
+	else
+		m_priv->objects.emplace_back(key, pObject);
 }
 
 const ObjectPtr& APRInitializer::findOrAddObject(size_t key, std::function<ObjectPtr()> creator)
 {
-#if APR_HAS_THREADS
-	std::unique_lock<std::mutex> lock(m_priv->mutex);
-#endif
-	auto pItem = m_priv->objects.find(key);
-	if (m_priv->objects.end() == pItem)
-		pItem = m_priv->objects.emplace(key, creator()).first;
-	return pItem->second;
+	std::lock_guard<std::mutex> lock(m_priv->mutex);
+	if (m_priv->objects.empty())
+	{
+		// Ensure the internal logger has a longer life than other Log4cxx static data
+		LogLog::debug(LOG4CXX_STR("Started"));
+	}
+	auto pItem = std::find_if(m_priv->objects.begin(), m_priv->objects.end()
+		, [key](const IdentifiedObject& item) { return item.first == key; }
+		);
+	if (m_priv->objects.end() != pItem)
+		return pItem->second;
+	m_priv->objects.emplace_back(key, creator());
+	return m_priv->objects.back().second;
 }
