@@ -224,6 +224,10 @@ AppenderPtr DOMConfigurator::parseAppender(Pool& p,
 	{
 		ObjectPtr instance = ObjectPtr(Loader::loadClass(className).newInstance());
 		AppenderPtr appender = LOG4CXX_NS::cast<Appender>(instance);
+		if(!appender){
+			LogLog::error(LOG4CXX_STR("Could not cast class of type [") + className + LOG4CXX_STR("] to appender"));
+			return AppenderPtr();
+		}
 		PropertySetter propSetter(appender);
 
 		appender->setName(subst(getAttribute(utf8Decoder, appenderElement, NAME_ATTR)));
@@ -295,7 +299,7 @@ AppenderPtr DOMConfigurator::parseAppender(Pool& p,
 			{
 				LogString refName = subst(getAttribute(utf8Decoder, currentElement, REF_ATTR));
 
-				if (appender->instanceof(AppenderAttachable::getStaticClass()))
+				if (!refName.empty() && appender->instanceof(AppenderAttachable::getStaticClass()))
 				{
 					AppenderAttachablePtr aa = LOG4CXX_NS::cast<AppenderAttachable>(appender);
 					if (LogLog::isDebugEnabled())
@@ -306,6 +310,10 @@ AppenderPtr DOMConfigurator::parseAppender(Pool& p,
 					}
 					aa->addAppender(findAppenderByReference(p, utf8Decoder, currentElement, doc, appenders));
 				}
+				else if (refName.empty())
+				{
+					LogLog::error(LOG4CXX_STR("Can't add appender with empty ref attribute"));
+				}
 				else
 				{
 					LogLog::error(LOG4CXX_STR("Requesting attachment of appender named [") +
