@@ -21,10 +21,10 @@
 #include <log4cxx/spi/location/locationinfo.h>
 #include <log4cxx/helpers/stringhelper.h>
 
-using namespace log4cxx;
-using namespace log4cxx::pattern;
-using namespace log4cxx::spi;
-using namespace log4cxx::helpers;
+using namespace LOG4CXX_NS;
+using namespace LOG4CXX_NS::pattern;
+using namespace LOG4CXX_NS::spi;
+using namespace LOG4CXX_NS::helpers;
 
 IMPLEMENT_LOG4CXX_OBJECT(LineLocationPatternConverter)
 
@@ -37,7 +37,7 @@ LineLocationPatternConverter::LineLocationPatternConverter() :
 PatternConverterPtr LineLocationPatternConverter::newInstance(
 	const std::vector<LogString>& /* options */)
 {
-	static PatternConverterPtr instance = std::make_shared<LineLocationPatternConverter>();
+	static WideLife<PatternConverterPtr> instance = std::make_shared<LineLocationPatternConverter>();
 	return instance;
 }
 
