@@ -26,40 +26,13 @@
 #include <log4cxx/rolling/timebasedrollingpolicy.h>
 #include <log4cxx/rolling/sizebasedtriggeringpolicy.h>
 #include <log4cxx/helpers/transcoder.h>
-#include <log4cxx/private/fileappender_priv.h>
+#include <log4cxx/private/rollingfileappender_priv.h>
 #include <mutex>
 
-using namespace log4cxx;
-using namespace log4cxx::rolling;
-using namespace log4cxx::helpers;
-using namespace log4cxx::spi;
-
-struct RollingFileAppender::RollingFileAppenderPriv : public FileAppenderPriv
-{
-	RollingFileAppenderPriv() :
-		FileAppenderPriv(),
-		fileLength(0) {}
-
-	/**
-	 * Triggering policy.
-	 */
-	TriggeringPolicyPtr triggeringPolicy;
-
-	/**
-	 * Rolling policy.
-	 */
-	RollingPolicyPtr rollingPolicy;
-
-	/**
-	 * Length of current active log file.
-	 */
-	size_t fileLength;
-
-	/**
-	 *  save the loggingevent
-	 */
-	spi::LoggingEventPtr _event;
-};
+using namespace LOG4CXX_NS;
+using namespace LOG4CXX_NS::rolling;
+using namespace LOG4CXX_NS::helpers;
+using namespace LOG4CXX_NS::spi;
 
 #define _priv static_cast<RollingFileAppenderPriv*>(m_priv.get())
 
@@ -69,8 +42,13 @@ IMPLEMENT_LOG4CXX_OBJECT(RollingFileAppender)
 /**
  * Construct a new instance.
  */
-RollingFileAppender::RollingFileAppender() :
-	FileAppender (std::make_unique<RollingFileAppenderPriv>())
+RollingFileAppender::RollingFileAppender()
+	: FileAppender(std::make_unique<RollingFileAppenderPriv>())
+{
+}
+
+RollingFileAppender::RollingFileAppender( std::unique_ptr<RollingFileAppenderPriv> priv )
+	: FileAppender(std::move(priv))
 {
 }
 
@@ -104,14 +82,14 @@ void RollingFileAppender::setOption(const LogString& option, const LogString& va
 int RollingFileAppender::getMaxBackupIndex() const
 {
 	int result = 1;
-	if (auto fwrp = log4cxx::cast<FixedWindowRollingPolicy>(_priv->rollingPolicy))
+	if (auto fwrp = LOG4CXX_NS::cast<FixedWindowRollingPolicy>(_priv->rollingPolicy))
 		result = fwrp->getMaxIndex();
 	return result;
 }
 
 void RollingFileAppender::setMaxBackupIndex(int maxBackups)
 {
-	auto fwrp = log4cxx::cast<FixedWindowRollingPolicy>(_priv->rollingPolicy);
+	auto fwrp = LOG4CXX_NS::cast<FixedWindowRollingPolicy>(_priv->rollingPolicy);
 	if (!fwrp)
 	{
 		fwrp = std::make_shared<FixedWindowRollingPolicy>();
@@ -124,14 +102,14 @@ void RollingFileAppender::setMaxBackupIndex(int maxBackups)
 size_t RollingFileAppender::getMaximumFileSize() const
 {
 	size_t result = 10 * 1024 * 1024;
-	if (auto sbtp = log4cxx::cast<SizeBasedTriggeringPolicy>(_priv->triggeringPolicy))
+	if (auto sbtp = LOG4CXX_NS::cast<SizeBasedTriggeringPolicy>(_priv->triggeringPolicy))
 		result = sbtp->getMaxFileSize();
 	return result;
 }
 
 void RollingFileAppender::setMaximumFileSize(size_t maxFileSize)
 {
-	auto sbtp = log4cxx::cast<SizeBasedTriggeringPolicy>(_priv->triggeringPolicy);
+	auto sbtp = LOG4CXX_NS::cast<SizeBasedTriggeringPolicy>(_priv->triggeringPolicy);
 	if (!sbtp)
 	{
 		sbtp = std::make_shared<SizeBasedTriggeringPolicy>();
@@ -185,7 +163,7 @@ LogString RollingFileAppender::makeFileNamePattern(const LogString& datePattern)
 
 void RollingFileAppender::setDatePattern(const LogString& newPattern)
 {
-	auto tbrp = log4cxx::cast<TimeBasedRollingPolicy>(_priv->rollingPolicy);
+	auto tbrp = LOG4CXX_NS::cast<TimeBasedRollingPolicy>(_priv->rollingPolicy);
 	if (!tbrp)
 	{
 		tbrp = std::make_shared<TimeBasedRollingPolicy>();
@@ -213,7 +191,7 @@ void RollingFileAppender::activateOptions(Pool& p)
 	//
 	if (!_priv->triggeringPolicy)
 	{
-		TriggeringPolicyPtr trig = log4cxx::cast<TriggeringPolicy>(_priv->rollingPolicy);
+		TriggeringPolicyPtr trig = LOG4CXX_NS::cast<TriggeringPolicy>(_priv->rollingPolicy);
 
 		if (trig != NULL)
 		{
@@ -336,18 +314,18 @@ bool RollingFileAppender::rolloverInternal(Pool& p)
 								}
 								catch (std::exception& ex)
 								{
-									LogString errorMsg = LOG4CXX_STR("Exception on rollover: ");
-									errorMsg.append(ex.what());
-									LogLog::error(errorMsg);
-									LogString exmsg;
-									log4cxx::helpers::Transcoder::decode(ex.what(), exmsg);
-									_priv->errorHandler->error(exmsg, ex, 0);
+									LogString msg(LOG4CXX_STR("Rollover of ["));
+									msg.append(getFile());
+									msg.append(LOG4CXX_STR("] failed"));
+									_priv->errorHandler->error(msg, ex, 0);
 								}
 							}
 
+							bool appendToExisting = true;
 							if (success)
 							{
-								if (rollover1->getAppend())
+								appendToExisting = rollover1->getAppend();
+								if (appendToExisting)
 								{
 									_priv->fileLength = File().setPath(rollover1->getActiveFileName()).length(p);
 								}
@@ -356,25 +334,24 @@ bool RollingFileAppender::rolloverInternal(Pool& p)
 									_priv->fileLength = 0;
 								}
 
-								//
-								//  async action not yet implemented
-								//
 								ActionPtr asyncAction(rollover1->getAsynchronous());
 
 								if (asyncAction != NULL)
 								{
-									asyncAction->execute(p);
+									try
+									{
+										asyncAction->execute(p);
+									}
+									catch (std::exception& ex)
+									{
+										LogString msg(LOG4CXX_STR("Rollover of ["));
+										msg.append(getFile());
+										msg.append(LOG4CXX_STR("] failed"));
+										_priv->errorHandler->error(msg, ex, 0);
+									}
 								}
-
-								setFileInternal(
-									rollover1->getActiveFileName(), rollover1->getAppend(),
-									_priv->bufferedIO, _priv->bufferSize, p);
-							}
-							else
-							{
-								setFileInternal(
-									rollover1->getActiveFileName(), true, _priv->bufferedIO, _priv->bufferSize, p);
 							}
+							setFileInternal(rollover1->getActiveFileName(), appendToExisting, _priv->bufferedIO, _priv->bufferSize, p);
 						}
 						else
 						{
@@ -399,12 +376,10 @@ bool RollingFileAppender::rolloverInternal(Pool& p)
 								}
 								catch (std::exception& ex)
 								{
-									LogString errorMsg = LOG4CXX_STR("Exception during rollover: ");
-									errorMsg.append(ex.what());
-									LogLog::warn(errorMsg);
-									LogString exmsg;
-									log4cxx::helpers::Transcoder::decode(ex.what(), exmsg);
-									_priv->errorHandler->error(exmsg, ex, 0);
+									LogString msg(LOG4CXX_STR("Rollover of ["));
+									msg.append(getFile());
+									msg.append(LOG4CXX_STR("] failed"));
+									_priv->errorHandler->error(msg, ex, 0);
 								}
 							}
 
@@ -419,9 +394,6 @@ bool RollingFileAppender::rolloverInternal(Pool& p)
 									_priv->fileLength = 0;
 								}
 
-								//
-								//   async action not yet implemented
-								//
 								ActionPtr asyncAction(rollover1->getAsynchronous());
 
 								if (asyncAction != NULL)
@@ -437,12 +409,10 @@ bool RollingFileAppender::rolloverInternal(Pool& p)
 				}
 				catch (std::exception& ex)
 				{
-					LogString errorMsg = LOG4CXX_STR("Exception during rollover: ");
-					errorMsg.append(ex.what());
-					LogLog::warn(errorMsg);
-					LogString exmsg;
-					log4cxx::helpers::Transcoder::decode(ex.what(), exmsg);
-					_priv->errorHandler->error(exmsg, ex, 0);
+					LogString msg(LOG4CXX_STR("Rollover of ["));
+					msg.append(getFile());
+					msg.append(LOG4CXX_STR("] failed"));
+					_priv->errorHandler->error(msg, ex, 0);
 				}
 		}
 	}
@@ -473,12 +443,10 @@ void RollingFileAppender::subAppend(const LoggingEventPtr& event, Pool& p)
 		}
 		catch (std::exception& ex)
 		{
-			LogString errorMsg = LOG4CXX_STR("Exception during rollover attempt: ");
-			errorMsg.append(ex.what());
-			LogLog::warn(errorMsg);
-			LogString exmsg;
-			log4cxx::helpers::Transcoder::decode(ex.what(), exmsg);
-			_priv->errorHandler->error(exmsg);
+			LogString msg(LOG4CXX_STR("Rollover of ["));
+			msg.append(getFile());
+			msg.append(LOG4CXX_STR("] failed"));
+			_priv->errorHandler->error(msg, ex, 0);
 		}
 	}
 
@@ -525,7 +493,7 @@ void RollingFileAppender::close()
 	FileAppender::close();
 }
 
-namespace log4cxx
+namespace LOG4CXX_NS
 {
 namespace rolling
 {
