@@ -20,7 +20,7 @@
 
 #include <log4cxx/helpers/writer.h>
 
-namespace log4cxx
+namespace LOG4CXX_NS
 {
 
 namespace helpers
@@ -50,6 +50,7 @@ class LOG4CXX_EXPORT BufferedWriter : public Writer
 		void flush(Pool& p) override;
 		void write(const LogString& str, Pool& p) override;
 
+		WriterPtr getWriter() const;
 	private:
 		BufferedWriter(const BufferedWriter&);
 		BufferedWriter& operator=(const BufferedWriter&);
