@@ -18,17 +18,11 @@
 #ifndef _LOG4CXX_SPI_APPENDER_ATTACHABLE_H_
 #define _LOG4CXX_SPI_APPENDER_ATTACHABLE_H_
 
-#if defined(_MSC_VER)
-	#pragma warning ( push )
-	#pragma warning ( disable: 4231 4251 4275 4786 )
-#endif
-
 #include <log4cxx/logstring.h>
-#include <vector>
 #include <log4cxx/helpers/object.h>
 #include <log4cxx/appender.h>
 
-namespace log4cxx
+namespace LOG4CXX_NS
 {
 namespace spi
 {
@@ -86,8 +80,5 @@ LOG4CXX_PTR_DEF(AppenderAttachable);
 }
 }
 
-#if defined(_MSC_VER)
-	#pragma warning ( pop )
-#endif
 
 #endif //_LOG4CXX_SPI_APPENDER_ATTACHABLE_H_
