@@ -20,9 +20,15 @@
 
 #include <log4cxx/log4cxx.h>
 #include <string>
-#include <log4cxx/helpers/objectoutputstream.h>
+#include <string.h>
 
-namespace log4cxx
+#if defined(_MSC_VER)
+#define LOG4CXX_SHORT_FILENAME_SPLIT_CHAR '\\'
+#else
+#define LOG4CXX_SHORT_FILENAME_SPLIT_CHAR '/'
+#endif
+
+namespace LOG4CXX_NS
 {
 namespace spi
 {
@@ -34,8 +40,6 @@ class LOG4CXX_EXPORT LocationInfo
 {
 	public:
 
-
-
 		/**
 		  *   When location information is not available the constant
 		  * <code>NA</code> is returned. Current value of this string constant is <b>?</b>.
@@ -45,7 +49,28 @@ class LOG4CXX_EXPORT LocationInfo
 
 		static const LocationInfo& getLocationUnavailable();
 
-
+		/**
+		 *   The part of \c fileName after the path.
+		 *
+		 *  Implemented to allow compile-time evaluation when called with a literal string
+		 */
+#if 201304L <= __cpp_constexpr
+		static constexpr const char* calcShortFileName(const char* fileName){
+#else
+		static const char* calcShortFileName(const char* fileName){
+#endif
+			if (fileName == nullptr) return nullptr;
+#if defined(_MSC_VER)
+			// As at 2024, the MSVC optimizer does not inline a function that calls another function
+			const char* location = nullptr;
+			for (auto p = fileName; *p; ++p)
+				if (*p == LOG4CXX_SHORT_FILENAME_SPLIT_CHAR)
+					location = p;
+#else
+			const char* location = strrchr(fileName, LOG4CXX_SHORT_FILENAME_SPLIT_CHAR);
+#endif
+			return location == nullptr ? fileName : location + 1;
+		}
 
 		/**
 		 *   Constructor.
@@ -53,8 +78,9 @@ class LOG4CXX_EXPORT LocationInfo
 		 *       location info for current code site
 		 */
 		LocationInfo( const char* const fileName,
-			const char* const functionName,
-			int lineNumber);
+					  const char* const shortFileName,
+					  const char* const functionName,
+					  int lineNumber);
 
 		/**
 		 *   Default constructor.
@@ -88,6 +114,13 @@ class LOG4CXX_EXPORT LocationInfo
 		 */
 		const char* getFileName() const;
 
+		/**
+		 *   Return the short file name of the caller.
+		 *   @returns file name.  Note that this will fallback to the full filename when using
+		 *    calcShortFileName to calculate the filename at compile-time.
+		 */
+		const char* getShortFileName() const;
+
 		/**
 		  *   Returns the line number of the caller.
 		  * @returns line number, -1 if not available.
@@ -97,8 +130,6 @@ class LOG4CXX_EXPORT LocationInfo
 		/** Returns the method name of the caller. */
 		const std::string getMethodName() const;
 
-		void write(log4cxx::helpers::ObjectOutputStream& os, log4cxx::helpers::Pool& p) const;
-
 
 	private:
 		/** Caller's line number. */
@@ -107,6 +138,9 @@ class LOG4CXX_EXPORT LocationInfo
 		/** Caller's file name. */
 		const char* fileName;
 
+  		/** Caller's short file name. */
+		const char* shortFileName;
+
 		/** Caller's method name. */
 		const char* methodName;
 
@@ -115,7 +149,7 @@ class LOG4CXX_EXPORT LocationInfo
 }
 }
 
-#if !defined(LOG4CXX_LOCATION)
+#if !defined(LOG4CXX_LOCATION) && !LOG4CXX_DISABLE_LOCATION_INFO
 #if defined(_MSC_VER)
 	#if _MSC_VER >= 1300
 		#define __LOG4CXX_FUNC__ __FUNCSIG__
@@ -130,11 +164,17 @@ class LOG4CXX_EXPORT LocationInfo
 	#endif
 #endif
 #if !defined(__LOG4CXX_FUNC__)
-	#define __LOG4CXX_FUNC__ ""
-#endif
-#define LOG4CXX_LOCATION ::log4cxx::spi::LocationInfo(__FILE__,         \
-	__LOG4CXX_FUNC__, \
-	__LINE__)
+	#define __LOG4CXX_FUNC__ nullptr
 #endif
 
+
+#define LOG4CXX_LOCATION ::LOG4CXX_NS::spi::LocationInfo(__FILE__,         \
+	::LOG4CXX_NS::spi::LocationInfo::calcShortFileName(__FILE__), \
+	__LOG4CXX_FUNC__, \
+	__LINE__)
+
+#else
+#define LOG4CXX_LOCATION ::LOG4CXX_NS::spi::LocationInfo::getLocationUnavailable()
+#endif // LOG4CXX_LOCATION
+
 #endif //_LOG4CXX_SPI_LOCATION_LOCATIONINFO_H
