@@ -20,7 +20,7 @@
 
 #include "filter.h"
 
-namespace log4cxx
+namespace LOG4CXX_NS
 {
 class AbsoluteTimeFilter : public Filter
 {
